<?php

/**
  * Badg
  * @category vidgets
  *
  * @author Roman Sviridov / ramzes_ra
  * @copyright ramzes_ra
  * @version 0.1
  */
  
class Dojo_Badge extends Module
{
	private $_html = '';
	private $_postErrors = array();

	function __construct()
	{
		$this->name = 'dojo_badge';
		$this->tab = 'Home';
		$this->version = '0.0.0';

		parent::__construct();

		$this->page = basename(__FILE__, '.php');
		$this->displayshort = $this->l('Badge of products on the home page');
		$this->description = $this->l('Display a badge of products in the middle of your homepage');
	}

	function install()
	{
		if (!Configuration::updateValue('DOJO_BADGE_NBR', 22) OR !parent::install() OR !$this->registerHook('home'))
			return false;
		if (!Configuration::updateValue('DOJO_BADGE_AUTOPLAY_DURATION', 100))
			return false;
		if (!Configuration::updateValue('DOJO_BADGE_SORT', 0))
			return false;
		if (!Configuration::updateValue('DOJO_BADGE_DISPLAY_SHORT', 1))
			return false;
		if (!Configuration::updateValue('DOJO_BADGE_SKIP_CAT', 1))
			return false;

		return true;
	}

	public function getContent()
	{
		$output = '<h2>'.$this->displayshort.'</h2>';
		if (Tools::isSubmit('submitBadge'))
		{
			$nbr = intval(Tools::getValue('nbr'));
			$sort = intval(Tools::getValue('sort'));
			$displayshort = intval(Tools::getValue('displayshort'));
				$skipcat = Tools::getValue('skipcat');
		
		if (!$nbr OR $nbr <= 0 OR !Validate::isInt($nbr))
				$errors[] = $this->l('Invalid number of product');
			else
			Configuration::updateValue('DOJO_BADGE_NBR', $nbr);
			Configuration::updateValue('DOJO_BADGE_SORT', $sort);
			Configuration::updateValue('DOJO_BADGE_DISPLAY_SHORT', $displayshort);
				
			if (!empty($skipcat))
			Configuration::updateValue('DOJO_BADGE_SKIP_CAT', implode(',',$skipcat));

			if (isset($errors) AND sizeof($errors))
				$output .= $this->displayError(implode('<br />', $errors));
			else
				$output .= $this->displayConfirmation($this->l('Settings updated'));
		}
		return $output.$this->displayForm();
	}
	
	function recurseCategory($categories, $current, $id_category = 1, $selectids_array)
	{
		global $currentIndex;		

		echo '<option value="'.$id_category.'"'.(in_array($id_category,$selectids_array) ? ' selected="selected"' : '').'>'.
		str_repeat('&nbsp;', $current['infos']['level_depth'] * 5) . preg_replace('/^[0-9]+\./', '', stripslashes($current['infos']['name'])) . '</option>';
		if (isset($categories[$id_category]))
			foreach ($categories[$id_category] AS $key => $row)
				$this->recurseCategory($categories, $categories[$id_category][$key], $key, $selectids_array);
	}
	

	public function displayForm()
	{
		global $cookie,$currentIndex;
	
		$output = '
					<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
						<fieldset><legend><img src="'.$this->_path.'logo.gif" alt="" title="" />'.$this->l('Settings').'</legend>
						
						<label>'.$this->l('Autoplay Badge').'</label>
						<div class="margin-form">
						
						<label>'.$this->l('Autoplay time').'</label>
						<div class="margin-form">
							<input type="text" size="5" name="autoplayduration" value="'.Tools::getValue('autoplayduration', Configuration::get('DOJO_BADGE_AUTOPLAY_DURATION')).'" />
							<p class="clear">'.$this->l('The time between each badge move. Default 100').'</p>
						</div>		
						<label>'.$this->l('Number of products in the badge').'</label>
						<div class="margin-form">
							<input type="text" size="5" name="nbr" value="'.Tools::getValue('nbr', Configuration::get('DOJO_BADGE_NBR')).'" />
							<p class="clear">'.$this->l('The number of products in the badge (ex. 11 OR 22 OR 33 etc.)[default: 22]').'</p>
						</div>
						
						
					';
				$output .= '		<label>'.$this->l('Display Product short description').'</label>
						<div class="margin-form">
							<input type="radio" name="displayshort" id="displayshort_on" value="1" '.(Tools::getValue('displayshort', Configuration::get('DOJO_BADGE_DISPLAY_SHORT')) ? 'checked="checked" ' : '').'/>
							<label class="t" for="displayshort_on"> <img src="../img/admin/enabled.gif" alt="'.$this->l('Enabled').'" title="'.$this->l('Enabled').'" /></label>
							<input type="radio" name="displayshort" id="displayshort_off" value="0" '.(!Tools::getValue('displayshort', Configuration::get('DOJO_BADGE_DISPLAY_SHORT')) ? 'checked="checked" ' : '').'/>
							<label class="t" for="displayshort_off"> <img src="../img/admin/disabled.gif" alt="'.$this->l('Disabled').'" title="'.$this->l('Disabled').'" /></label>
						</div></br> ';

		$skipcat = Configuration::get('DOJO_BADGE_SKIP_CAT');
		
		if (!empty($skipcat))
		{
			$skipcat_array = explode(',',$skipcat);
		}
		else
		{
			$skipcat_array = array();
		}
		
		$output .= '<label>'.$this->l('Shop categories to skip').'</label>
						<div class="margin-form">		
							<select name="skipcat[]" multiple="multiple">';
		$categories = Category::getCategories(intval($cookie->id_lang));
		ob_start();
		$this->recurseCategory($categories, $categories[0][1], 1, $skipcat_array);
		$output .= ob_get_contents();
		ob_end_clean();
		$output .= '
							</select>
							<p class="clear">'.$this->l('Select the categories you want to exclude from the carousel (Hold CTRL to select multiples)').'</p>									
						</div>						
					';
				
		$output .= '
						<label>'.$this->l('Choice of sort').'</label>
						<div class="margin-form">
							<select name="sort" id="sort">
								<option value="0" '.(Configuration::get('DOJO_BADGE_SORT') == 0 ? 'selected' : '').'>'.$this->l('No Sort - Sort by Back Office => Catalogue -> Position').'</option>
								<option value="1" '.(Configuration::get('DOJO_BADGE_SORT') == 1 ? 'selected' : '').'>'.$this->l('Random').'</option>
								<option value="2" '.(Configuration::get('DOJO_BADGE_SORT') == 2 ? 'selected' : '').'>'.$this->l('Price Asc').'</option>
								<option value="3" '.(Configuration::get('DOJO_BADGE_SORT') == 3 ? 'selected' : '').'>'.$this->l('Price Desc').'</option>
								<option value="4" '.(Configuration::get('DOJO_BADGE_SORT') == 4 ? 'selected' : '').'>'.$this->l('Last update in first').'</option>
								<option value="5" '.(Configuration::get('DOJO_BADGE_SORT') == 5 ? 'selected' : '').'>'.$this->l('Last add in first').'</option>
								<option value="6" '.(Configuration::get('DOJO_BADGE_SORT') == 6 ? 'selected' : '').'>'.$this->l('Alphabetical').'</option>
							</select>
						</div>	
						
						<center><input type="submit" name="submitBadge" value="'.$this->l('Save').'" class="button" /></center>
		
					</fieldset>
				</form>
			  ';
		return $output;
	}

	public function getProducts($idcat, $id_lang, $p, $n, $orderBy = NULL, $orderWay = NULL)
	{
		global $cookie;

		if (empty($idcat))
		{
			return false;
		}

		if ($p < 1) $p = 1;
		if (empty($orderBy))
			$orderBy = 'position';
		if (empty($orderWay))
			$orderWay = 'ASC';
		if ($orderBy == 'id_product' OR	$orderBy == 'price' OR	$orderBy == 'date_add')
			$orderByPrefix = 'p';
		elseif ($orderBy == 'name')
			$orderByPrefix = 'pl';
		elseif ($orderBy == 'manufacturer')
		{
			$orderByPrefix = 'm';
			$orderBy = 'name';
		}
		elseif ($orderBy == 'position')
			$orderByPrefix = 'cp';

		$sql = '
		SELECT p.*, pl.`description_short`,   pl.`link_rewrite`, pl.`name`, i.`id_image`,cl.`link_rewrite` AS category_rewrite, DATEDIFF(p.`date_add`, DATE_SUB(NOW(), INTERVAL '.(Validate::isUnsignedInt(Configuration::get('PS_NB_DAYS_NEW_PRODUCT')) ? Configuration::get('PS_NB_DAYS_NEW_PRODUCT') : 20).' DAY)) > 0 AS new
		FROM `'._DB_PREFIX_.'category_product` cp
		LEFT JOIN `'._DB_PREFIX_.'product` p ON (p.`id_product` = cp.`id_product`)
		LEFT JOIN `'._DB_PREFIX_.'category_lang` cl ON (p.`id_category_default` = cl.`id_category` AND cl.`id_lang` = '.intval($id_lang).')
		LEFT JOIN `'._DB_PREFIX_.'product_lang` pl ON (p.`id_product` = pl.`id_product` AND pl.`id_lang` = '.intval($id_lang).')
		LEFT JOIN `'._DB_PREFIX_.'image` i ON (i.`id_product` = p.`id_product` AND i.`cover` = 1)
		LEFT JOIN `'._DB_PREFIX_.'image_lang` il ON (i.`id_image` = il.`id_image` AND il.`id_lang` = '.intval($id_lang).')
		WHERE cp.`id_category` NOT IN ('.$idcat.') AND p.`active` = 1
		GROUP BY cp.`id_product`
		ORDER BY '.(isset($orderByPrefix) ? $orderByPrefix.'.' : '').'`'.pSQL($orderBy).'` '.pSQL($orderWay).'
		LIMIT '.((intval($p) - 1) * intval($n)).','.intval($n);
		
		$result = Db::getInstance()->ExecuteS($sql);
		
		if ($orderBy == 'price')
			Tools::orderbyPrice($result, $orderWay);
		if (!$result)
			return false;

		return Product::getProductsProperties($id_lang, $result);
	}

	function hookHome($params)
	{
		global $smarty;
		
		$nr = intval(Configuration::get('DOJO_BADGE_NBR')/11);
		$nb = $nr*11;
		if($nr<2)$nr=2;
		$sort = intval(Configuration::get('DOJO_BADGE_SORT'));
		$skipcategory = Configuration::get('DOJO_BADGE_SKIP_CAT');

		switch ($sort) {
		    case '0':
			$products = $this->getProducts($skipcategory,intval($params['cookie']->id_lang), 1, ($nb ? $nb : 10));
			break;
		    case '1':
			$products = $this->getProducts($skipcategory,intval($params['cookie']->id_lang), 1, 1000);
			shuffle($products);
			array_splice($products, ($nb ? $nb : 10));
			break;
		    case '2':
			$products = $this->getProducts($skipcategory,intval($params['cookie']->id_lang), 1, ($nb ? $nb : 10), 'price', 'ASC');  
			break;
		    case '3':
			$products = $this->getProducts($skipcategory,intval($params['cookie']->id_lang), 1, ($nb ? $nb : 10), 'price', 'DESC');  
			break;
		    case '4':
			$products = $this->getProducts(intval($skipcategory,$params['cookie']->id_lang), 1, ($nb ? $nb : 10), 'date_upd', 'DESC');  
			break;
		    case '5':
			$products = $this->getProducts(intval($skipcategory,$params['cookie']->id_lang), 1, ($nb ? $nb : 10), 'date_add', 'DESC');  
			break;
		    case '6':
			$products = $this->getProducts(intval($skipcategory,$params['cookie']->id_lang), 1, ($nb ? $nb : 10), 'name', 'ASC');  
			break;
		    default:
			$products = $this->getProducts(intval($skipcategory,$params['cookie']->id_lang), 1, ($nb ? $nb : 10));
			break;
		}
		$short_yes=Configuration::get('DOJO_BADGE_DISPLAY_SHORT');
				foreach($products AS $product){
		$images[]='img/p/'.$product['id_image'] .'-home.jpg';
		$lnk[]=$product['category_rewrite'].'/'.$product['id_product'].'-'.$product['link_rewrite'].'.html'; 
			if($short_yes)$tips[]=$product['description_short'];
				}
		if($short_yes){
$smarty->assign('tips',$tips);
		}
		$smarty->assign('rows',$nr);
$smarty->assign('arr_images',$images);
	$smarty->assign('arr_lnk',$lnk);
$smarty->assign('autoplayduration',Configuration::get('DOJO_BADGE_AUTOPLAY_DURATION'));
		return $this->display(__FILE__, 'dojo_badge.tpl');
	}


   
}
